@@ -221,7 +221,7 @@ class TakemeClient:
         self.non_auth_call(body, endpoint)
 
     def corporate_change_pin(self, old_pin, new_pin):
-        endpoint = "user/change-pin"
+        endpoint = "corporate/change-pin"
         body = {
             "old_pin": RsaUtil.encrypt(old_pin),
             "new_pin": RsaUtil.encrypt(new_pin)
@@ -230,7 +230,7 @@ class TakemeClient:
         self.non_auth_call(body, endpoint)
 
     def corporate_topup_user(self, phone_number, amount, pin):
-        endpoint = "user/topup-user"
+        endpoint = "corporate/topup-user"
         body = {
             "phone_number": phone_number,
             "amount": amount
@@ -239,7 +239,7 @@ class TakemeClient:
         self.non_auth_call_with_pin(body, endpoint, pin)
 
     def corporate_deduct_user(self, phone_number, amount, pin):
-        endpoint = "user/deduct-user"
+        endpoint = "corporate/deduct-user"
         body = {
             "phone_number": phone_number,
             "amount": amount
